==> haskell-th-desugar-1.9-34-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-th-desugar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-desugar
version: 1.9
id: th-desugar-1.9-EzlKzLkqO8NAdonrLdbcLK
key: th-desugar-1.9-EzlKzLkqO8NAdonrLdbcLK
license: BSD-3-Clause
maintainer: Ryan Scott <ryan.gl.scott@gmail.com>
author: Richard Eisenberg <rae@cs.brynmawr.edu>
stability: experimental
homepage: https://github.com/goldfirere/th-desugar
synopsis: Functions to desugar Template Haskell
description:
    This package provides the Language.Haskell.TH.Desugar module, which desugars
    Template Haskell'\''s rich encoding of Haskell syntax into a simpler encoding.
    This desugaring discards surface syntax information (such as the use of infix
    operators) but retains the original meaning of the TH code. The intended use
    of this package is as a preprocessor for more advanced code manipulation
    tools. Note that the input to any of the ds... functions should be produced
    from a TH quote, using the syntax [| ... |]. If the input to these functions
    is a hand-coded TH syntax tree, the results may be unpredictable. In
    particular, it is likely that promoted datatypes will not work as expected.
category: Template Haskell
abi: 93a93b2564830c0d46b794e8dfde315d
exposed: True
exposed-modules:
    Language.Haskell.TH.Desugar Language.Haskell.TH.Desugar.Expand
    Language.Haskell.TH.Desugar.Lift Language.Haskell.TH.Desugar.Subst
    Language.Haskell.TH.Desugar.Sweeten
hidden-modules: Language.Haskell.TH.Desugar.AST
                Language.Haskell.TH.Desugar.Core Language.Haskell.TH.Desugar.Match
                Language.Haskell.TH.Desugar.Util Language.Haskell.TH.Desugar.Reify
import-dirs: /usr/lib/ghc-8.6.5/site-local/th-desugar-1.9
library-dirs: /usr/lib/ghc-8.6.5/site-local/th-desugar-1.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/th-desugar-1.9
hs-libraries: HSth-desugar-1.9-EzlKzLkqO8NAdonrLdbcLK
depends:
    base-4.12.0.0 containers-0.6.0.1 mtl-2.2.2
    syb-0.7.1-1gO4OjQOULM8usUjWwwEyW template-haskell-2.14.0.0
    th-expand-syns-0.4.4.0-ACeG5Fd2nA9J5jHwfmyY63
    th-lift-0.8.0.1-27iw5a8l71Jv8yDjPHfmr
    th-orphans-0.13.7-3p9top26QmdL7WioCb2df
haddock-interfaces: /usr/share/doc/haskell-th-desugar/html/th-desugar.haddock
haddock-html: /usr/share/doc/haskell-th-desugar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-desugar-1.9-35-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-th-desugar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-desugar
version: 1.9
id: th-desugar-1.9-JIzJObppbHfG267eNtofCY
key: th-desugar-1.9-JIzJObppbHfG267eNtofCY
license: BSD-3-Clause
maintainer: Ryan Scott <ryan.gl.scott@gmail.com>
author: Richard Eisenberg <rae@cs.brynmawr.edu>
stability: experimental
homepage: https://github.com/goldfirere/th-desugar
synopsis: Functions to desugar Template Haskell
description:
    This package provides the Language.Haskell.TH.Desugar module, which desugars
    Template Haskell'\''s rich encoding of Haskell syntax into a simpler encoding.
    This desugaring discards surface syntax information (such as the use of infix
    operators) but retains the original meaning of the TH code. The intended use
    of this package is as a preprocessor for more advanced code manipulation
    tools. Note that the input to any of the ds... functions should be produced
    from a TH quote, using the syntax [| ... |]. If the input to these functions
    is a hand-coded TH syntax tree, the results may be unpredictable. In
    particular, it is likely that promoted datatypes will not work as expected.
category: Template Haskell
abi: 9d0aa3d6075022d7f37c71cdbc763eed
exposed: True
exposed-modules:
    Language.Haskell.TH.Desugar Language.Haskell.TH.Desugar.Expand
    Language.Haskell.TH.Desugar.Lift Language.Haskell.TH.Desugar.Subst
    Language.Haskell.TH.Desugar.Sweeten
hidden-modules: Language.Haskell.TH.Desugar.AST
                Language.Haskell.TH.Desugar.Core Language.Haskell.TH.Desugar.Match
                Language.Haskell.TH.Desugar.Util Language.Haskell.TH.Desugar.Reify
import-dirs: /usr/lib/ghc-8.6.5/site-local/th-desugar-1.9
library-dirs: /usr/lib/ghc-8.6.5/site-local/th-desugar-1.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/th-desugar-1.9
hs-libraries: HSth-desugar-1.9-JIzJObppbHfG267eNtofCY
depends:
    base-4.12.0.0 containers-0.6.0.1 mtl-2.2.2
    syb-0.7.1-1gO4OjQOULM8usUjWwwEyW template-haskell-2.14.0.0
    th-expand-syns-0.4.5.0-9MmbxLXOBDyEihN0YbdbeC
    th-lift-0.8.0.1-27iw5a8l71Jv8yDjPHfmr
    th-orphans-0.13.7-HghHJKVho5DVkBF1DPzmR
haddock-interfaces: /usr/share/doc/haskell-th-desugar/html/th-desugar.haddock
haddock-html: /usr/share/doc/haskell-th-desugar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
